@@ -1,6 +1,7 @@
 from setuptools import Extension
 from setuptools.command.build_py import build_py as build_py_orig
 from setuptools.command.install import install as _install
+import shutil
 
 from Cython.Build import cythonize
 import os
@@ -32,7 +33,7 @@ def get_install(setup_py):
                 return
             else:
                 dirname = os.path.split(setup_py)[0]
-                os.remove(os.path.join(dirname, "build"))
+                shutil.rmtree(os.path.join(dirname, "build"))
                 for root, subdirs, files in os.walk(dirname):
                     for fname in os.listdir(root):
                         fname.endswith('.c')
